<?php
/**
 * Functions that return the color patterns for the Figure/Ground theme.
 */

require( 'color-calculations.php' );

function linework_lw_colors_css() {
	$lw_light = get_theme_mod( 'lw_background_color', '#fffcf7' );
	$lw_dark = get_theme_mod( 'linework_color', '#2200aa' );

	// Defaults for both, so don't need to do anything.
	if ( '#fffcf7' === $lw_light && '#2200aa' === $lw_dark ) {
		return '';
	}

	$css = '';

	// Check contrast between figure/ground colors. @todo: move to customizer validation function on each color control.
	if ( 4.5 > linework_contrast_ratio( $lw_light, $lw_dark ) ) {
		// Ensure that the light color is lighter than the dark color.
		if ( linework_relative_luminance( $lw_dark ) > linework_relative_luminance( $lw_light ) ) {
			$lw_test_light = $lw_dark;
			$lw_test_dark = $lw_light;
		} else {
			$lw_test_light = $lw_light;
			$lw_test_dark = $lw_dark;
		}
		// There isn't enough contrast, so we need to adjust the chosen colors.
		// Start by lightening light, up to white.
		while ( 4.5 > linework_contrast_ratio( $lw_test_light, $lw_test_dark )
				&& 1 > linework_relative_luminance( $lw_test_light ) ) {
					$lw_test_light = linework_adjust_color( $lw_test_light, 8 );
				}
		// Do we need to do more?
		if ( 4.5 > linework_contrast_ratio( $lw_test_light, $lw_test_dark ) ) {
			// Darken the dark color until we get there (should never reach anywhere near black).
			while ( 4.5 > linework_contrast_ratio( $lw_test_light, $lw_test_dark )
					&& 0 < linework_relative_luminance( $lw_test_dark ) ) {
						$lw_test_dark = linework_adjust_color( $lw_test_dark, -8 );
					}
		}
		if ( linework_relative_luminance( $lw_dark ) > linework_relative_luminance( $lw_light ) ) {
			$lw_light = $lw_test_dark;
			$lw_dark = $lw_test_light;
		} else {
			$lw_light = $lw_test_light;
			$lw_dark = $lw_test_dark;
		}
	}

	// Background color.
	$css .= '
	body,
	.site,
	.main-navigation,
	.main-navigation ul a,
	.screen-reader-text:focus,
	.site .mejs-controls .mejs-time-rail .mejs-time-loaded,
	.site .mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-current,
	.has-contrast-background-color,
	#linework-animation-toggle {
		background-color: ' . $lw_light . ';
	}';

	// Text & linework color.
	$css .= '
	.button:hover,
	.wp-block-button__link:hover,
	.site .entry-content .button:hover,
	.site .entry-content .wp-block-file__button:hover,
	.site .entry-content .wp-block-button__link:hover,
	button:hover,
	input[type="button"]:hover,
	input[type="reset"]:hover,
	input[type="submit"]:hover,
	.button:focus,
	.wp-block-button__link:focus,
	.site .entry-content .button:focus,
	.site .entry-content .wp-block-file__button:focus,
	.site .entry-content .wp-block-button__link:focus,
	button:focus,
	input[type="button"]:focus,
	input[type="reset"]:focus,
	input[type="submit"]:focus,
	.button:active,
	.wp-block-button__link:active,
	.site .entry-content .button:active,
	.site .entry-content .wp-block-file__button:active,
	.site .entry-content .wp-block-button__link:active,
	button:active,
	input[type="button"]:active,
	input[type="reset"]:active,
	input[type="submit"]:active,
	.site .mejs-controls .mejs-time-rail .mejs-time-current,
	.has-linework-background-color,
	#linework-animation-toggle:focus,
	#linework-animation-toggle:hover {
	    background-color: ' . $lw_dark . ';
	}

	.has-contrast-color,
	#linework-animation-toggle:focus,
	#linework-animation-toggle:hover {
		color: ' . $lw_light . ';
	}

	a,
	body,
	button,
	input,
	select,
	textarea,
	.screen-reader-text:focus,
	.has-linework-color,
	#linework-animation-toggle {
		color: ' . $lw_dark . ';
	}

	.button:hover,
	.wp-block-button__link,
	.site .entry-content .button:hover,
	.site .entry-content .wp-block-file__button:hover,
	.site .entry-content .wp-block-button__link:hover,
	button:hover,
	input[type="button"]:hover,
	input[type="reset"]:hover,
	input[type="submit"]:hover,
	.button:focus,
	.wp-block-button__link:focus,
	.site .entry-content .button:focus,
	.site .entry-content .wp-block-file__button:focus,
	.site .entry-content .wp-block-button__link:focus,
	button:focus,
	input[type="button"]:focus,
	input[type="reset"]:focus,
	input[type="submit"]:focus,
	.button:active,
	.wp-block-button__link:active,
	.site .entry-content .button:active,
	.site .entry-content .wp-block-file__button:active,
	.site .entry-content .wp-block-button__link:active,
	button:active,
	input[type="button"]:active,
	input[type="reset"]:active,
	input[type="submit"]:active,
	#linework-animation-toggle {
		border-color: ' . $lw_dark . ';
	}';

	// If the  background is too dark for the black highlight color, use white if it provides higher contrast.
	if ( 4.5 > linework_contrast_ratio( $lw_light, '#000' ) && linework_contrast_ratio( $lw_light, '#000' ) < linework_contrast_ratio( $lw_light, '#fff' ) ) {
		$css.= '
		a:hover,
		a:focus,
		a:active,
		.main-navigation .current_page_item > a,
		.main-navigation .current-menu-item > a,
		.main-navigation .current_page_ancestor > a,
		.main-navigation .current-menu-ancestor > a {
			color: #fff;
		}';
	}

	return $css;
}